@@ -1,9 +1,18 @@
 import os
 
 BATCH_SIZE = int(os.getenv("BATCH_SIZE", "0"))
-MESSAGING_TIMEOUT = float(os.getenv("MESSAGING_TIMEOUT", "0"))
+CALL_TIMEOUT = (
+    float(os.environ["CALL_TIMEOUT"]) if "CALL_TIMEOUT" in os.environ else None
+)
+MESSAGING_TIMEOUT = (
+    float(os.environ["MESSAGING_TIMEOUT"])
+    if "MESSAGING_TIMEOUT" in os.environ
+    else None
+)
 PROCESSING_TIMEOUT = (
-    float(os.environ["PROCESSING_TIMEOUT"]) if "PROCESSING_TIMEOUT" in os.environ else None
+    float(os.environ["PROCESSING_TIMEOUT"])
+    if "PROCESSING_TIMEOUT" in os.environ
+    else None
 )
 RESENDS = int(os.getenv("RESENDS", "0"))
 RETRIES = int(os.getenv("RETRIES", "0"))
