@@ -6,7 +6,6 @@ from pydantic import BaseModel
 from pydantic.generics import GenericModel
 from types import TracebackType
 from typing import (
-    Any,
     AsyncIterator,
     Generic,
     Optional,
@@ -59,26 +58,30 @@ class MessagingABC(abc.ABC):
 
 
 class TopicABC(abc.ABC, Generic[T]):
+    @property
     @abc.abstractmethod
-    def header(self, **kwargs: Any) -> HeaderABC[T]:
+    def header_type(self) -> Type[HeaderABC[T]]:
         raise NotImplementedError
 
     def __init__(
         self,
         name: str,
         messaging: MessagingABC,
+        schema_type: Type[T],
         serializer_type: Type[SerializerABC] = Serializer,
     ):
         self.name = name
         self.messaging = messaging
+        self.schema_type = schema_type
         self.serializer_type = serializer_type
 
+    @abc.abstractmethod
     async def serialize(self, header: HeaderABC[T]) -> bytes:
-        return await self.serializer_type.serialize(header.dict())
+        raise NotImplementedError
 
+    @abc.abstractmethod
     async def deserialize(self, serialized: bytes) -> HeaderABC[T]:
-        data = await self.serializer_type.deserialize(serialized)
-        return self.header(**data)
+        raise NotImplementedError
 
     async def subscribe(self, group_name: str) -> None:
         pass
